pype32

Package pype32 |
[hide private]
[frames] | no frames]

# Package pype32

source code

Yet another Python library to work with PE32 and PE64 file formats.

by Nahuel Riva (crackinglandia at gmail.com)

Project: http://code.google.com/p/pype32

Blog: http://crackinglandia.blogspot.com

Submodules | [hide private]
pype32.baseclasses: Base classes. pype32.consts: Common definitions. pype32.datadirs: Data directory classes. pype32.datatypes: Data types objects. pype32.directories: PE directory classes. pype32.excep: Exceptions used by the entire library. pype32.pype32: Common PE structures. pype32.utils: Auxiliary classes and functions.

Classes | [hide private]
PE
| DosHeader DosHeader object.
| FileHeader FileHeader object.
| NtHeaders NtHeaders object.
| OptionalHeader OptionalHeader object.
| OptionalHeader64 OptionalHeader64 object.
| PE PE object.
| SectionHeader SectionHeader object.
| SectionHeaders SectionHeaders object.
| Sections Sections object.
Data type objects
| String String object.
| AlignedString Aligned string object.
| Array Array object.
| BYTE Byte object.
| WORD Word object.
| DWORD Dword object.
| QWORD Qword object.
Utilities
| ReadData Returns a ReadData-like stream object.
| WriteData Return a WriteData-like stream object for writing.
Exceptions
| ArrayTypeException Raised when creating an unsupported type of array.
| DataLengthException Raised when data lengths does not match.
| DataMismatchException Raised when two different types of data does not match.
| DirectoryEntriesLengthException Raised when the the number of entries in a DataDirectory object is different from consts.IMAGE_NUMBEROF_DIRECTORY_ENTRIES.
| DirectoryEntryException This exception must be raised when an error with the Directory is found.
| InstanceErrorException This exception is raised when an instance parameter was not specified.
| InvalidParameterException Raised when an invalid parameter is received.
| NotValidPathException Raised when a path wasn't found or it is an invalid path.
| PyPe32Exception Base exception class.
| ReadDataOffsetException This exception must be raised when reading from an invalid offset.
| SectionHeadersException Raised when an error related to a pype32.SectionHeader or pype32.SectionHeaders is found.
| TypeNotSupportedException This exception must be used when an invalid data type is used within the library.
| WriteDataOffsetException This exception must be raised when writing to an invalid offset.
| WrongOffsetValueException Used primary by the ReadData and WriteData object in read/write operations when an invalid offset value was used.
Directories
| Directory Directory object.
| DataDirectory DataDirectory object.
| ExportTable Array of ExportTableEntry objects.
| ExportTableEntry ExportTableEntry object.
| ImageBaseRelocation ImageBaseRelocation array.
| ImageBaseRelocationEntry ImageBaseRelocationEntry object.
| ImageBoundForwarderRef ImageBoundForwarderRef array object.
| ImageBoundForwarderRefEntry ImageBoundForwarderRefEntry object.
| ImageBoundImportDescriptor ImageBoundImportDescriptor object.
| ImageBoundImportDescriptorEntry ImageBoundImportDescriptorEntry object.
| ImageDebugDirectories ImageDebugDirectories object.
| ImageDebugDirectory ImageDebugDirectory object.
| ImageExportTable ImageExportTable object.
| ImageImportDescriptor ImageImportDescriptor object.
| ImageImportDescriptorEntry ImageImportDescriptorEntry object.
| ImageImportDescriptorMetaData ImageImportDescriptorMetaData object.
| ImportAddressTable Array of ImportAddressTableEntry objects.
| ImportAddressTableEntry ImportAddressTableEntry object.
| ImportAddressTableEntry64 ImportAddressTableEntry64 object.
| NETDirectory NETDirectory object.
| NetDirectory NetDirectory object.
| NetMetaDataHeader NetMetaDataHeader object.
| NetMetaDataStreamEntry NetMetaDataStreamEntry object.
| NetMetaDataStreams NetMetaDataStreams object.
| NetMetaDataTableHeader NetMetaDataTableHeader object.
| NetMetaDataTables NetMetaDataTables object.
| TLSDirectory TLS directory object.
| TLSDirectory64 TLSDirectory64 object.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| version_number = `0.1`
str | version = ``'``Version 0.1``'`` This pype32 release version.
| __package__ = ``'``pype32``'``